package at.ac.uibk.gitsearch.service.dto;

import java.util.Map;

import org.elasticsearch.search.SearchHit;
import org.elasticsearch.search.fetch.subphase.highlight.HighlightField;

import at.ac.uibk.gitsearch.es.model.DocumentInfo;
import at.ac.uibk.gitsearch.repository.search.SearchRepositoryConstants;

public class GitFilesDTO {

    private final String content;
    private final FragmentDTO fragment;
    private final String fileFormat;
    private final String repository;
    private final String url;
    private final String subGroup;
    private final String fileExtension;
    private final String fileName;
    private final String filePath;
    private final String gitUrl;

    public GitFilesDTO(DocumentInfo documentInfo, SearchHit searchHit, String preTag, String postTag) {
        this.content = documentInfo.getContent();

        Map<String, HighlightField> highlightFields = searchHit.getHighlightFields();
        String highlightedFragement = highlightFields.get(SearchRepositoryConstants.FULLTEXT_CONTENT).getFragments()[0].string();
        this.fragment = new FragmentDTO().matchFillLine(documentInfo.getContent(), highlightedFragement, preTag, postTag);

        this.fileFormat = documentInfo.getFile().getFile_format();
        this.repository = documentInfo.getProject().getProject_name();
        this.url = documentInfo.getProject().getUrl();
        this.subGroup = documentInfo.getProject().getSub_group();
        this.fileExtension = documentInfo.getFile().getExtension();
        this.fileName = documentInfo.getFile().getFilename();
        this.filePath = documentInfo.getProject().getNamespace() + "/" + documentInfo.getFile().getFilename();
        this.gitUrl = documentInfo.getProject().getUrl() + "/-/blob/master/" + documentInfo.getFile().getCommit_id() + "/" + filePath;
    }

    public String getContent() {
        return content;
    }

    public FragmentDTO getFragment() {
        return fragment;
    }

    public String getFileFormat() {
        return fileFormat;
    }

    public String getRepository() {
        return repository;
    }

    public String getUrl() {
        return url;
    }

    public String getSubGroup() {
        return subGroup;
    }

    public String getFileExtension() {
        return fileExtension;
    }

    public String getFileName() {
        return fileName;
    }

    public String getFilePath() {
        return filePath;
    }

    public String getGitUrl() {
        return gitUrl;
    }
}
